package de.intevation.gnv.state;

import java.util.Collection;
import java.util.List;

/**
 * @author Tim Englich (tim.englich@intevation.de)
 * @author Ingo Weinzierl (ingo.weinzierl@intevation.de)
 */
public class DefaultOutputMode implements OutputMode {

    /**
     * The UID of this Class.
     */
    private static final long serialVersionUID = -6459085460904827056L;
    private String name = null;
    private String description = null;
    private String mimeType = null;
    private Collection<InputValue> inputParameters = null;
    private List<ExportMode> exportModes;

    /**
     * Constructor
     *
     * @param name
     * @param description
     * @param mimeType
     */
    public DefaultOutputMode(
        String name,
        String description,
        String mimeType,
        Collection<InputValue> inputParameters,
        List<ExportMode> exportModes)
    {
        super();
        this.name            = name;
        this.description     = description;
        this.mimeType        = mimeType;
        this.inputParameters = inputParameters;
        this.exportModes     = exportModes;
    }

    /**
     * @see de.intevation.gnv.state.OutputMode#getDescription()
     */
    public String getDescription() {
        return this.description;
    }

    /**
     * @see de.intevation.gnv.state.OutputMode#getMimeType()
     */
    public String getMimeType() {
        return this.mimeType;
    }

    /**
     * @see de.intevation.gnv.state.OutputMode#getName()
     */
    public String getName() {
        return this.name;
    }

    /**
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return "Name: " + this.name + " ; Description: " + this.description
               + " ; Mime-Type: " + this.mimeType;
    }

    /**
     * @see de.intevation.gnv.state.OutputMode#getInputParameters()
     */
    public Collection<InputValue> getInputParameters() {
        return this.inputParameters;
    }

    public List<ExportMode> getExportModes() {
        return exportModes;
    }

}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
